@@ -15,22 +15,24 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Authors: Glynn Foster <glynn.foster@sun.com>
  */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
 #include <sys/types.h>
+#include <unistd.h>
 #include <signal.h>
 #include <glade/glade.h>
 #include "zenity.h"
 #include "util.h"
 
-static guint timer;
 static GladeXML *glade_dialog;
 static ZenityData *zen_data;
 static GIOChannel *channel;
@@ -151,6 +153,11 @@ zenity_progress_handle_stdin (GIOChannel   *channel,
     if (glade_dialog)
       g_object_unref (glade_dialog);
 
+    if (progress_data->autoclose) {
+      zen_data->exit_code = zenity_util_return_exit_code (ZENITY_OK);
+      gtk_main_quit();
+    }
+		
     g_io_channel_shutdown (channel, TRUE, NULL);
     return FALSE;
   }
